@@ -65,7 +65,7 @@ func BenchmarkContainerRender(b *testing.B) {
 	b.ReportAllocs()
 	b.ResetTimer()
 	for n := 0; n < b.N; n++ {
-		c.Render(cres, "blee", &r)
+		_ = c.Render(cres, "blee", &r)
 	}
 }
 
