@@ -4,6 +4,7 @@ import (
 	"encoding/json"
 	"errors"
 	"fmt"
+	"github.com/rs/zerolog/log"
 	"strings"
 
 	"github.com/derailed/k9s/internal/client"
@@ -16,6 +17,7 @@ const ageTableCol = "Age"
 type Generic struct {
 	Base
 	table    *metav1beta1.Table
+	header   Header
 	ageIndex int
 }
 
@@ -24,8 +26,9 @@ func (*Generic) IsGeneric() bool {
 }
 
 // SetTable sets the tabular resource.
-func (g *Generic) SetTable(t *metav1beta1.Table) {
+func (g *Generic) SetTable(ns string, t *metav1beta1.Table) {
 	g.table = t
+	g.header = g.Header(ns)
 }
 
 // ColorerFunc colors a resource row.
@@ -35,6 +38,9 @@ func (*Generic) ColorerFunc() ColorerFunc {
 
 // Header returns a header row.
 func (g *Generic) Header(ns string) Header {
+	if g.header != nil {
+		return g.header
+	}
 	if g.table == nil {
 		return Header{}
 	}
@@ -89,6 +95,8 @@ func (g *Generic) Render(o interface{}, ns string, r *Row) error {
 	}
 	if d, ok := duration.(string); ok {
 		r.Fields = append(r.Fields, d)
+	} else {
+		log.Warn().Msgf("No Duration detected on age field")
 	}
 
 	return nil
