@@ -38,6 +38,13 @@ func ShowDelete(styles config.Dialog, pages *ui.Pages, msg string, ok okFunc, ca
 	f.AddDropDown("Propagation:", propagationOptions, defaultPropagationIdx, func(_ string, optionIndex int) {
 		propagation = propagationOptions[optionIndex]
 	})
+	propField := f.GetFormItemByLabel("Propagation:").(*tview.DropDown)
+	propField.SetListStyles(
+		styles.FgColor.Color(),
+		styles.BgColor.Color(),
+		styles.ButtonFocusFgColor.Color(),
+		styles.ButtonFocusBgColor.Color(),
+	)
 	f.AddCheckbox("Force:", force, func(_ string, checked bool) {
 		force = checked
 	})
