@@ -5,7 +5,6 @@ import (
 
 	"github.com/derailed/k9s/internal/client"
 	"github.com/derailed/k9s/internal/dao"
-	"github.com/derailed/k9s/internal/render"
 	"github.com/derailed/k9s/internal/ui"
 	"github.com/gdamore/tcell/v2"
 	"github.com/rs/zerolog/log"
@@ -22,7 +21,6 @@ func NewContext(gvr client.GVR) ResourceViewer {
 		ResourceViewer: NewBrowser(gvr),
 	}
 	c.GetTable().SetEnterFn(c.useCtx)
-	c.GetTable().SetColorerFn(render.Context{}.ColorerFunc())
 	c.AddBindKeysFn(c.bindKeys)
 
 	return &c
