@@ -35,8 +35,10 @@ func NewScreenDump(gvr client.GVR) ResourceViewer {
 
 func (s *ScreenDump) dirContext(ctx context.Context) context.Context {
 	dir := filepath.Join(s.App().Config.K9s.GetScreenDumpDir(), s.App().Config.K9s.CurrentContextDir())
-	log.Debug().Msgf("SD-DIR %q", dir)
-	config.EnsureFullPath(dir, config.DefaultDirMod)
+	if err := config.EnsureFullPath(dir, config.DefaultDirMod); err != nil {
+		s.App().Flash().Err(err)
+		return ctx
+	}
 
 	return context.WithValue(ctx, internal.KeyDir, dir)
 }
